==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/teuchos/src/Teuchos_XMLParameterListWriter.hpp <==
// @HEADER
// ***********************************************************************
// 
//                    Teuchos: Common Tools Package
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef Teuchos_XMLPARAMETERLISTWRITER_H
#define Teuchos_XMLPARAMETERLISTWRITER_H

/*! \file Teuchos_XMLParameterListWriter.hpp
    \brief Writes a ParameterList to an XML object
*/

#include "Teuchos_ParameterList.hpp"
#include "Teuchos_XMLObject.hpp"
#include "Teuchos_Utils.hpp"

namespace Teuchos
{

	/** \ingroup XML 
	 * \brief Writes a ParameterList to an XML object
	 */

	class XMLParameterListWriter
		{
		public:
      //! @name Constructors 
			//@{
      /** Construct a writer */
      XMLParameterListWriter();
			//@}

      /** Write the given list to an XML object */
      XMLObject toXML(const ParameterList& p) const ;
	
		private:

      /** Write the given parameter entry to an XML object */
      XMLObject toXML(const ParameterEntry& p) const ;
		};
}
#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/teuchos/src/Teuchos_XMLParameterListWriter.hpp <==
// @HEADER
// ***********************************************************************
// 
//                    Teuchos: Common Tools Package
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef Teuchos_XMLPARAMETERLISTWRITER_H
#define Teuchos_XMLPARAMETERLISTWRITER_H

/*! \file Teuchos_XMLParameterListWriter.hpp
    \brief Writes a ParameterList to an XML object
*/

#include "Teuchos_ParameterList.hpp"
#include "Teuchos_XMLObject.hpp"
#include "Teuchos_Utils.hpp"

namespace Teuchos
{

	/** \ingroup XML 
	 * \brief Writes a ParameterList to an XML object
	 */

	class TEUCHOS_LIB_DLL_EXPORT XMLParameterListWriter
		{
		public:
      //! @name Constructors 
			//@{
      /** Construct a writer */
      XMLParameterListWriter();
			//@}

      /** Write the given list to an XML object */
      XMLObject toXML(const ParameterList& p) const ;
	
		private:

      /** Write the given parameter entry to an XML object */
      XMLObject toXML(const ParameterEntry& p) const ;
		};
}
#endif
